@@ -8,11 +8,10 @@ use URI::Escape  ();
 use IO::File     ();
 use File::Spec::Functions qw(canonpath);
 
-require Exporter;
+use base qw(Exporter);
+our @EXPORT = qw(serve_static);
 
-our $VERSION = '0.05';
-our @ISA     = qw(Exporter);
-our @EXPORT  = qw(serve_static);
+our $VERSION = '0.06';
 
 my $mime  = MIME::Types->new();
 my $magic = File::MMagic->new();
@@ -36,14 +35,41 @@ sub serve_static {
         }
         $fh->close;
 
+        my $content_length;
+        if ( defined $content ) {
+            use bytes;    # Content-Length in bytes, not characters
+            $content_length = length $content;
+        }
+        else {
+            $content_length = 0;
+            $content        = q{};
+        }
+
+        # If a file has no extension, e.g. 'foo' this will return undef
         my $mimeobj = $mime->mimeTypeOf($path);
-        my $mime    = ($mimeobj ? $mimeobj->type :
-                       $magic->checktype_contents($content));
+
+        my $mimetype;
+        if ( defined $mimeobj ) {
+            $mimetype = $mimeobj->type;
+        }
+        else {
+
+            # If the file is empty File::MMagic will give the MIME type as
+            # application/octet-stream' which is not helpful and not the
+            # way other web servers act. So, we default to 'text/plain'
+            # which is the same as apache.
+
+            if ($content_length) {
+                $mimetype = $magic->checktype_contents($content);
+            }
+            else {
+                $mimetype = 'text/plain';
+            }
+        }
 
-        use bytes;      # Content-Length in bytes, not characters
         print "HTTP/1.1 200 OK\015\012";
-        print "Content-type: " . $mime . "\015\012";
-        print "Content-length: " . length($content) . "\015\012\015\012";
+        print 'Content-type: ' . $mimetype . "\015\012";
+        print 'Content-length: ' . $content_length . "\015\012\015\012";
         print $content;
         return 1;
     }
@@ -59,31 +85,39 @@ HTTP::Server::Simple::Static - Serve static files with HTTP::Server::Simple
 
 =head1 SYNOPSIS
 
-    use base 'HTTP::Server::Simple::CGI';
+    package MyServer;
+
+    use base qw(HTTP::Server::Simple::CGI);
     use HTTP::Server::Simple::Static;
 
     sub handle_request {
-	my ($self,$cgi) = @_;
-	return $self->serve_static($cgi,$webroot);
+	my ( $self, $cgi ) = @_;
+	return $self->serve_static( $cgi, $webroot );
     }
 
+    package main;
+
+    my $server = MyServer->new();
+    $server->run();
+
 =head1 DESCRIPTION
 
 this mixin adds a method to serve static files from your HTTP::Server::Simple
 subclass.
 
 
-=head1 METHODS
+=head1 SUBROUTINES/METHODS
 
 =over 4
 
 =item  serve_static
 
-Takes a base directory and a web path, and tries to serve a static file.
+Takes a base directory and a web path, and tries to serve a static
+file. Returns 0 if the file does not exist, returns 1 on success.
 
 =back
 
-=head1 BUGS
+=head1 BUGS AND LIMITATIONS
 
 Bugs or wishlist requests should be submitted via http://rt.cpan.org/
 
@@ -96,7 +130,9 @@ Stephen Quinney C<sjq-perl@jadevine.org.uk>
 Thanks to Marcus Ramberg C<marcus@thefeed.no> and Simon Cozens for
 initial implementation.
 
-=head1 LICENSE
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2006, 2007. Stephen Quinney C<sjq-perl@jadevine.org.uk>
 
 You may distribute this code under the same terms as Perl itself.
 
